Module runtime

Module runtime 

Traits

ActorCode
Interface for invoking methods on an Actor
MessageInfo
Message information available to the actor about executing message.
Runtime
Runtime is the VM’s internal runtime object. this is everything that is accessible to actors, beyond parameters.
Syscalls
Pure functions implemented as primitives by the runtime.