ActorCode

Trait ActorCode 

pub trait ActorCode {
    // Required method
    fn invoke_method<BS, RT>(
        rt: &mut RT,
        method: MethodNum,
        params: &RawBytes,
    ) -> Result<RawBytes, ActorError>
       where BS: Blockstore,
             RT: Runtime<BS>;
}
Interface for invoking methods on an Actor

Required Methods

fn invoke_method<BS, RT>( rt: &mut RT, method: MethodNum, params: &RawBytes, ) -> Result<RawBytes, ActorError>
where BS: Blockstore, RT: Runtime<BS>,

Invokes method with runtime on the actor’s code. Method number will match one defined by the Actor, and parameters will be serialized and used in execution

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors