BalanceTable

Struct BalanceTable 

pub struct BalanceTable<'a, BS>(/* private fields */);
Balance table which handles getting and updating token balances specifically

Implementations

Source

impl<'a, BS> BalanceTable<'a, BS>
where BS: Blockstore,

pub fn new(bs: &'a BS) -> Self

Initializes a new empty balance table

pub fn from_root(bs: &'a BS, cid: &Cid) -> Result<Self, Error>

Initializes a balance table from a root Cid

pub fn root(&mut self) -> Result<Cid, Error>

Retrieve root from balance table

pub fn get(&self, key: &Address) -> Result<TokenAmount, Error>

Gets token amount for given address in balance table

pub fn add(&mut self, key: &Address, value: &TokenAmount) -> Result<(), Error>

Adds token amount to previously initialized account.

pub fn subtract_with_minimum( &mut self, key: &Address, req: &TokenAmount, floor: &TokenAmount, ) -> Result<TokenAmount, Error>

Subtracts up to the specified amount from a balance, without reducing the balance below some minimum. Returns the amount subtracted (always positive or zero).

pub fn must_subtract( &mut self, key: &Address, req: &TokenAmount, ) -> Result<(), Error>

Subtracts value from a balance, and errors if full amount was not substracted.

pub fn total(&self) -> Result<TokenAmount, Error>

Returns total balance held by this balance table