Multimap

Struct Multimap 

pub struct Multimap<'a, BS>(/* private fields */);
Multimap stores multiple values per key in a Hamt of Amts. The order of insertion of values for each key is retained.

Implementations

Source

impl<'a, BS> Multimap<'a, BS>
where BS: Blockstore,

pub fn new(bs: &'a BS, outer_bitwidth: u32, inner_bitwidth: u32) -> Self

Initializes a new empty multimap. The outer_bitwidth is the width of the HAMT and the inner_bitwidth is the width of the AMTs inside of it.

pub fn from_root( bs: &'a BS, cid: &Cid, outer_bitwidth: u32, inner_bitwidth: u32, ) -> Result<Self, Error>

Initializes a multimap from a root Cid

pub fn root(&mut self) -> Result<Cid, Error>

Retrieve root from the multimap.

pub fn add<V>(&mut self, key: BytesKey, value: V) -> Result<(), Error>

Adds a value for a key.

pub fn get<V>(&self, key: &[u8]) -> Result<Option<Array<'a, V, BS>>, Error>

Gets the Array of value type V using the multimap store.

pub fn remove_all(&mut self, key: &[u8]) -> Result<(), Error>

Removes all values for a key.

pub fn for_each<F, V>(&self, key: &[u8], f: F) -> Result<(), Error>

Iterates through all values in the array at a given key.

pub fn for_all<F, V>(&self, f: F) -> Result<(), Error>
where V: Serialize + DeserializeOwned, F: FnMut(&BytesKey, &Array<'_, V, BS>) -> Result<()>,

Iterates through all arrays in the multimap