Set

Struct Set 

pub struct Set<'a, BS>(/* private fields */);
Set is a Hamt with empty values for the purpose of acting as a hash set.

Implementations

Source

impl<'a, BS> Set<'a, BS>
where BS: Blockstore,

pub fn new(bs: &'a BS) -> Self

Initializes a new empty Set with the default bitwidth.

pub fn new_set_with_bitwidth(bs: &'a BS, bitwidth: u32) -> Self

Initializes a new empty Set given a bitwidth.

pub fn from_root(bs: &'a BS, cid: &Cid) -> Result<Self, Error>

Initializes a Set from a root Cid.

pub fn root(&mut self) -> Result<Cid, Error>

Retrieve root from the Set.

pub fn put(&mut self, key: BytesKey) -> Result<(), Error>

Adds key to the set.

pub fn has(&self, key: &[u8]) -> Result<bool, Error>

Checks if key exists in the set.

pub fn delete(&mut self, key: &[u8]) -> Result<Option<()>, Error>

Deletes key from set.

pub fn for_each<F>(&self, f: F) -> Result<(), Error>
where F: FnMut(&BytesKey) -> Result<()>,

Iterates through all keys in the set.

pub fn collect_keys(&self) -> Result<Vec<BytesKey>, Error>

Collects all keys from the set into a vector.