SetMultimap

Struct SetMultimap 

pub struct SetMultimap<'a, BS>(/* private fields */);
SetMultimap is a hamt with values that are also a hamt but are of the set variant. This allows hash sets to be indexable by an address.

Implementations

Source

impl<'a, BS> SetMultimap<'a, BS>
where BS: Blockstore,

pub fn new(bs: &'a BS) -> Self

Initializes a new empty SetMultimap.

pub fn from_root(bs: &'a BS, cid: &Cid) -> Result<Self, Error>

Initializes a SetMultimap from a root Cid.

pub fn root(&mut self) -> Result<Cid, Error>

Retrieve root from the SetMultimap.

pub fn put(&mut self, key: ChainEpoch, value: DealID) -> Result<(), Error>

Puts the DealID in the hash set of the key.

pub fn put_many( &mut self, key: ChainEpoch, values: &[DealID], ) -> Result<(), Error>

Puts slice of DealIDs in the hash set of the key.

pub fn get(&self, key: ChainEpoch) -> Result<Option<Set<'a, BS>>, Error>

Gets the set at the given index of the SetMultimap

pub fn remove(&mut self, key: ChainEpoch, v: DealID) -> Result<(), Error>

Removes a DealID from a key hash set.

pub fn remove_all(&mut self, key: ChainEpoch) -> Result<(), Error>

Removes set at index.

pub fn for_each<F>(&self, key: ChainEpoch, f: F) -> Result<(), Error>
where F: FnMut(DealID) -> Result<(), Error>,

Iterates through keys and converts them to a DealID to call a function on each.