Traits
- Actor
Code - Interface for invoking methods on an Actor
- Message
Info - Message information available to the actor about executing message.
- Runtime
- Runtime is the VM’s internal runtime object. this is everything that is accessible to actors, beyond parameters.
- Syscalls
- Pure functions implemented as primitives by the runtime.