Module util
Source - chaos
- BalanceTable
- Balance table which handles getting and updating token balances specifically
- Multimap
- Multimap stores multiple values per key in a Hamt of Amts.
The order of insertion of values for each key is retained.
- Set
- Set is a Hamt with empty values for the purpose of acting as a hash set.
- SetMultimap
- SetMultimap is a hamt with values that are also a hamt but are of the set variant.
This allows hash sets to be indexable by an address.
- BALANCE_TABLE_BITWIDTH
- ActorDowncast
- Trait to allow multiple error types to be able to be downcasted into an
ActorError.