pub struct SetMultimap<'a, BS>(/* private fields */);Expand description
SetMultimap is a hamt with values that are also a hamt but are of the set variant. This allows hash sets to be indexable by an address.
Implementations
Sourceimpl<'a, BS> SetMultimap<'a, BS>where
BS: Blockstore,
impl<'a, BS> SetMultimap<'a, BS>where
BS: Blockstore,
Sourcepub fn from_root(bs: &'a BS, cid: &Cid) -> Result<Self, Error>
pub fn from_root(bs: &'a BS, cid: &Cid) -> Result<Self, Error>
Initializes a SetMultimap from a root Cid.
Sourcepub fn put(&mut self, key: ChainEpoch, value: DealID) -> Result<(), Error>
pub fn put(&mut self, key: ChainEpoch, value: DealID) -> Result<(), Error>
Puts the DealID in the hash set of the key.
Sourcepub fn put_many(
&mut self,
key: ChainEpoch,
values: &[DealID],
) -> Result<(), Error>
pub fn put_many( &mut self, key: ChainEpoch, values: &[DealID], ) -> Result<(), Error>
Puts slice of DealIDs in the hash set of the key.
Sourcepub fn get(&self, key: ChainEpoch) -> Result<Option<Set<'a, BS>>, Error>
pub fn get(&self, key: ChainEpoch) -> Result<Option<Set<'a, BS>>, Error>
Gets the set at the given index of the SetMultimap
Sourcepub fn remove(&mut self, key: ChainEpoch, v: DealID) -> Result<(), Error>
pub fn remove(&mut self, key: ChainEpoch, v: DealID) -> Result<(), Error>
Removes a DealID from a key hash set.
Sourcepub fn remove_all(&mut self, key: ChainEpoch) -> Result<(), Error>
pub fn remove_all(&mut self, key: ChainEpoch) -> Result<(), Error>
Removes set at index.